Contributors
============

Development
-----------

* Lead developer: Nicolas Hainaux

* Developers: Vaibhav Gupta

* Clever advices: Olivier Cecillon

Translation
-----------

* French: Nicolas Hainaux

Problems wordings
-----------------

Nicolas Hainaux

Patience and chocolate cakes
----------------------------

Sophie Reboud